@@ -171,7 +171,7 @@ while(<>){
 		$specifier = $PS_IMPER;
 	  } elsif(!/ .*/o) {
 		$specifier = $PS_VERB;
-	  } elsif(/ .*/) {
+	  } elsif(/ .*/o || m:,/:o) {
 		$specifier = $PS_NONDEF;
 	  } else {
 		$specifier = $PS_ALL;
